/**

*/
import java.awt.Color;
import java.io.FileInputStream;
import java.io.IOException;

public class PPM2FrameBuffer
{
   public static FrameBuffer ppm2FramBuffer(String inputFileName)
   {
      int height = 0;
      int width  = 0;
      FrameBuffer fb = null;

      // Read the pixel data in a PPM file.
      // http://stackoverflow.com/questions/2693631/read-ppm-file-and-store-it-in-an-array-coded-with-c
      try
      {
         FileInputStream fis = new FileInputStream(inputFileName);

         // Read image format string "P6".
         String magicNumber = "";
         char c = (char)fis.read();
         while (c != '\n')
         {
            magicNumber += c;
            c = (char)fis.read();
         }
         if (! magicNumber.trim().startsWith("P6"))
         {
            System.err.printf("ERROR! Improper PPM number in file %s\n", inputFileName);
            System.exit(-1);
         }

         c = (char)fis.read();
         if ( '#' == c ) // read (and discard) IrfanView comment
         {
            while (c != '\n')
            {
               c = (char)fis.read();
            }
            c = (char)fis.read();
         }

         // Read image dimensions.
         String widthDim = "";
         while (c != ' ' && c != '\n')
         {
            widthDim += c;
            c = (char)fis.read();
         }
         width = Integer.parseInt(widthDim.trim());

         String heightDim = "";
         c = (char)fis.read();
         while (c != '\n')
         {
            heightDim += c;
            c = (char)fis.read();
         }
         height = Integer.parseInt(heightDim.trim());

         // Read image rgb dimensions (which we don't use).
         c = (char)fis.read();
         while (c != '\n')
         {
            c = (char)fis.read();
         }

         // Create a FrameBuffer to hold the image.
         fb = new FrameBuffer(width, height);

         // Create a data array.
         byte[] pixelData = new byte[3];
         // Read pixel data, one pixel at a time, from the PPM file.
         for (int y = 0; y < height; y++)
         {
            for (int x = 0; x < width; x++)
            {
               if ( fis.read(pixelData, 0, 3) != 3 )
               {
                  System.err.printf("ERROR! Could not load %s\n", inputFileName);
                  System.exit(-1);
               }
               int r = pixelData[0];
               int g = pixelData[1];
               int b = pixelData[2];
               if (r < 0) r = 256+r;  // convert from signed byte to unsigned byte
               if (g < 0) g = 256+g;
               if (b < 0) b = 256+b;
               fb.setPixelFB(x, y, new Color(r, g, b));
            }
         }
         fis.close();
      }
      catch (IOException e)
      {
         e.printStackTrace(System.err);
         System.err.printf("ERROR! Could not read %s\n", inputFileName);
         System.exit(-1);
      }
      return fb;
   }
}